==> pegasus-support-1.6.30-sources.jar: com/thebeastshop/support/vo/product/DownSpvVO.java <==
package com.thebeastshop.support.vo.product;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

import com.thebeastshop.support.Label;
import com.thebeastshop.support.enums.flowerMonth.FlowerMonthDistType;
import com.thebeastshop.support.vo.product.SimpleProductVO.DiscVO;
import com.thebeastshop.support.vo.product.SimpleProductVO.PriceForecastVO;
import com.thebeastshop.support.vo.product.SpvVO.BrandVO;

/**
 * 定金规格
 * 
 * @author wyw
 *
 */
public class DownSpvVO implements Serializable{
	private Long spvId;// 真实商品spvid

	private Long virtual;// 虚拟spv

	private Integer stock;// 虚拟库存

	private BigDecimal price;// 定金

	private BigDecimal deduction;// 抵扣

	private BigDecimal finalPrice;// 尾款

	public Long getSpvId() {
		return spvId;
	}

	public void setSpvId(Long spvId) {
		this.spvId = spvId;
	}

	public Long getVirtual() {
		return virtual;
	}

	public void setVirtual(Long virtual) {
		this.virtual = virtual;
	}

	public Integer getStock() {
		return stock;
	}

	public void setStock(Integer stock) {
		this.stock = stock;
	}

	public BigDecimal getPrice() {
		return price;
	}

	public void setPrice(BigDecimal price) {
		this.price = price;
	}

	public BigDecimal getDeduction() {
		return deduction;
	}

	public void setDeduction(BigDecimal deduction) {
		this.deduction = deduction;
	}

	public BigDecimal getFinalPrice() {
		return finalPrice;
	}

	public void setFinalPrice(BigDecimal finalPrice) {
		this.finalPrice = finalPrice;
	}

	@Override
	public String toString() {
		final StringBuffer sb = new StringBuffer("DownSpvVO{");
		sb.append("spvId=").append(spvId);
		sb.append(", virtual=").append(virtual);
		sb.append(", stock=").append(stock);
		sb.append(", price=").append(price);
		sb.append(", deduction=").append(deduction);
		sb.append(", finalPrice=").append(finalPrice);
		sb.append('}');
		return sb.toString();
	}
}

==> pegasus-support-2.2.7-sources.jar: com/thebeastshop/support/vo/product/DownSpvVO.java <==
package com.thebeastshop.support.vo.product;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

import com.thebeastshop.support.Label;
import com.thebeastshop.support.enums.flowerMonth.FlowerMonthDistType;
import com.thebeastshop.support.vo.product.SimpleProductVO.DiscVO;
import com.thebeastshop.support.vo.product.SimpleProductVO.PriceForecastVO;
import com.thebeastshop.support.vo.product.SpvVO.BrandVO;

/**
 * 定金规格
 * 
 * @author wyw
 *
 */
public class DownSpvVO implements Serializable{
	private Long spvId;// 真实商品spvid

	private Long virtual;// 虚拟spv

	private Integer stock;// 虚拟库存

	private BigDecimal price;// 定金

	private BigDecimal deduction;// 抵扣

	private BigDecimal finalPrice;// 尾款

	private String tip;      //定金商品提示信息

	public Long getSpvId() {
		return spvId;
	}

	public void setSpvId(Long spvId) {
		this.spvId = spvId;
	}

	public Long getVirtual() {
		return virtual;
	}

	public void setVirtual(Long virtual) {
		this.virtual = virtual;
	}

	public Integer getStock() {
		return stock;
	}

	public void setStock(Integer stock) {
		this.stock = stock;
	}

	public BigDecimal getPrice() {
		return price;
	}

	public void setPrice(BigDecimal price) {
		this.price = price;
	}

	public BigDecimal getDeduction() {
		return deduction;
	}

	public void setDeduction(BigDecimal deduction) {
		this.deduction = deduction;
	}

	public BigDecimal getFinalPrice() {
		return finalPrice;
	}

	public void setFinalPrice(BigDecimal finalPrice) {
		this.finalPrice = finalPrice;
	}

	public String getTip() {
		return tip;
	}

	public void setTip(String tip) {
		this.tip = tip;
	}

	@Override
	public String toString() {
		final StringBuffer sb = new StringBuffer("DownSpvVO{");
		sb.append("spvId=").append(spvId);
		sb.append(", virtual=").append(virtual);
		sb.append(", stock=").append(stock);
		sb.append(", price=").append(price);
		sb.append(", deduction=").append(deduction);
		sb.append(", finalPrice=").append(finalPrice);
		sb.append(", tip=").append(tip);
		sb.append('}');
		return sb.toString();
	}
}
